PathParams

Trait PathParams 

pub trait PathParams: DowncastSync + DynClone {
    // Required methods
    fn size(&self) -> usize;
    fn get(&self, _index: usize) -> (Option<&str>, String);
    fn set(
        &mut self,
        _index: usize,
        _name_and_value: &(Option<&str>, &str),
    ) -> Result<(), SetError>;
    fn verify(
        &self,
        _index: usize,
        _name_and_value: &(Option<&str>, &str),
    ) -> Result<(), SetError>;

    // Provided methods
    fn info(&self) -> PathParamsInfo { ... }
    fn set_from_info(&mut self, info: &PathParamsInfo) -> Result<(), SetError> { ... }
}

Required Methods

fn size(&self) -> usize

fn get(&self, _index: usize) -> (Option<&str>, String)

fn set( &mut self, _index: usize, _name_and_value: &(Option<&str>, &str), ) -> Result<(), SetError>

fn verify( &self, _index: usize, _name_and_value: &(Option<&str>, &str), ) -> Result<(), SetError>

Provided Methods

Implementations

Source

impl dyn PathParams

pub fn is<__T: PathParams>(&self) -> bool

Returns true if the trait object wraps an object of type __T.

pub fn downcast<__T: PathParams>(self: Box<Self>) -> Result<Box<__T>, Box<Self>>

Returns a boxed object from a boxed trait object if the underlying object is of type __T. Returns the original boxed trait if it isn’t.

pub fn downcast_rc<__T: PathParams>(self: Rc<Self>) -> Result<Rc<__T>, Rc<Self>>

Returns an Rc-ed object from an Rc-ed trait object if the underlying object is of type __T. Returns the original Rc-ed trait if it isn’t.

pub fn downcast_ref<__T: PathParams>(&self) -> Option<&__T>

Returns a reference to the object within the trait object if it is of type __T, or None if it isn’t.

pub fn downcast_mut<__T: PathParams>(&mut self) -> Option<&mut __T>

Returns a mutable reference to the object within the trait object if it is of type __T, or None if it isn’t.